L.Control.ScaleBar = L.Class.extend({

onAdd: function (map) {
    this._pixelwidth = 100;

    this._map = map;
    this._maptrigger_move = this._map.on('moveend', this._update, this);
    this._maptrigger_zoom = this._map.on('zoomend', this._update, this);

    this._container = L.DomUtil.create('div', 'leaflet-control-scalebar');
    this._container.style.overflow =  'hidden';
    this._container.style.width  = this._pixelwidth + 'px';
    this._container.style.position  = "absolute";
    this._container.style.bottom  = "5px";
    this._container.style.left  = "5px";
    this._container.style.height =  '15px';
    this._container.style.backgroundColor =  'hsla(0,0%,100%,0.8)';
    this._container.style.borderColor =  'black';
    this._container.style.borderStyle =  'solid';
    this._container.style.borderWidth =  '0 1px 1px 1px';
    this._container.style.fontSize =  '8pt';
    this._container.style.textAlign =  'center';
	
    document.getElementById("map").appendChild(this._container);
    this._update();
},

onRemove: function (map) {
    map.off('moveend', this._maptrigger_move, this);
    map.off('zoomend', this._maptrigger_zoom, this);
},

getPosition: function () {
    return L.Control.Position.BOTTOM_LEFT;
},

getContainer: function () {
	alert(this._container.innerHTML);
    return this._container;
},

_update: function () {
    if (!this._map) return;

    // find the vertical midpoint of the left-hand and right-hand sides of the map viewport
    var bounds = this._map.getBounds();
    var sw = bounds.getSouthWest();
    var ne = bounds.getNorthEast();
    var halflat = ( sw.lat + ne.lat ) / 2.0;
    var midLeft  = new L.LatLng(halflat,sw.lng);
    var midRight = new L.LatLng(halflat,ne.lng);

    // find the distance between those two points (meters) and divide by the map's pixel width,
    // and we have the meters-per-pixel at the moment
    var mwidth  = midLeft.distanceTo(midRight);
    var pxwidth = this._map.getSize().x;
    var mperpx = mwidth / pxwidth;

    // now we know the distance represented by our scalebar, which is this._pixelwidth pixels wide
    var meters    = this._pixelwidth * mperpx;
    var feet      = meters * 3.2808399;
    var miles     = meters * 0.000621371192;
    var feet_txt  = Math.round(feet) + ' ft';
    var miles_txt = miles.toFixed(2) + ' mi';
    //console.log([meters,feet,miles]);

    // make up some text and assign it
    var unitstext = feet < 1320 ? feet_txt : miles_txt;
    // metric
    if(meters < 100){
	unitstext = Math.round(meters)+"m"
    }else{
	unitstext=Math.round(meters/10)/100+"km"
    }
    this._container.innerHTML = unitstext;
}
});
